==> hinemos_agent-2.2.2_rhel3_yomosugar.tar.gz: Hinemos_Agent-2.2.2_rhel3_Yomosugar/agent_installer_JP.sh <==
#!/bin/sh

#Copyright (C) 2006, 2007 NTT DATA Corporation
#
#This program is free software; you can redistribute it and/or
#Modify it under the terms of the GNU General Public License
#as published by the Free Software Foundation, version 2.
#
#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details

#ɤ߹ 
export EXEC_PATH=${0%/*}

. ${EXEC_PATH}/install.cfg

echo ""
                                                                                
echo "###################################################################"
echo "###                                                             ###"
echo "### Ѵեȥ Hinemos                    ###"
echo "###                                   󥹥ȡ   Ver 2.2.2  ###"
echo "###                                                             ###"
echo "###  Copyright (C) 2006,2007 NTT DATA Corporation.              ###"
echo "###################################################################"


EXEC_USER=`/usr/bin/whoami`
HOSTS_FILE=/etc/hosts
HOST=`hostname`

# check for incorrect user

if [ $EXEC_USER != "root" ]; then
        echo "";
        echo "ERROR  Hinemos AgentΥ󥹥ȡrootǤʤäƤ ";
        echo "";
        exit 1;
fi

pre_install() {
	##
	## hostsեΥå START
	##
	echo ""
	echo "󥹥ȡԤˡ${HOSTS_FILE} ΥåԤޤ"
	echo ""
	
	#ۥ̾IPɥ쥹νʣʤåԤ
	check_flg=`grep ${HOST} ${HOSTS_FILE} | grep -v ^\# | awk '{print $1}' | wc -l`
	
	if [ ${check_flg} != 1 ]; then
	    echo "NG"
	    echo "${HOSTS_FILE} ϡ${HOST} ФIPɥ쥹꤬ԤƤʤ2İʾIPɥ쥹ꤵƤޤ"
	    echo "ĤȤʤ褦ѹƲ"
	    echo ""
	    exit 1
	fi
	echo "OK"
	
	##
	## hostsեΥå END
	##
	
	
	##
	## ѥåΥå START
	##
	echo ""
	echo "󥹥ȡԤˡѥåΥåԤޤ"
	
	# ѥå̵ͭå
	rpm_check() {
	    rpm -qi $1 >/dev/null 2>&1
	    check_flg=$?
	}
	
	# ޥ˥奢˵ҤƤѥå̵ͭå
	for p_name in ${CHECK_MAN[@]}
	do
	    rpm_check ${p_name}
	    if [ ${check_flg} = 1 ]; then
	        echo ${p_name} >> ${EXEC_PATH}/tmp.txt
	    fi
	done
	
	# ̤ɽ
	if [ -s ${EXEC_PATH}/tmp.txt ]; then
	    echo ""
	    echo "NG"
	    echo "HinemosȤ򥤥󥹥ȡ뤹ˤϰʲΥѥå­Ƥޤ"
	    cat ${EXEC_PATH}/tmp.txt
	    echo ""
	    echo "ܺ٤ˤĤƤϥ󥹥ȡޥ˥奢 P8 򻲾ȤƲ"
	    echo ""
	    rm -rf ${EXEC_PATH}/tmp.txt
	    exit 1
	else
	    rm -rf ${EXEC_PATH}/tmp.txt
	fi
	
	# 󥹥ȡ뤹ѥåΰ¸طå
	for p_name in "${CHECK_RPMS[@]}"
	do
	    rpm -U --force --nosignature --test "${p_name}" >/dev/null 2>> ${EXEC_PATH}/tmp.txt
	done
	
	#̤ɽ
	if [ -s ${EXEC_PATH}/tmp.txt ]; then
	    echo "NG"
	    echo "HinemosȤ򥤥󥹥ȡ뤹ˤϰʲΥѥå­Ƥޤ"
	    cat ${EXEC_PATH}/tmp.txt |grep -v : |awk '{print $1}'
	    echo ""
	    echo "ܺ٤ˤĤƤϥ󥹥ȡޥ˥奢 P8 򻲾ȤƲ"
	    echo ""
	    rm -rf ${EXEC_PATH}/tmp.txt
	    exit 1
	else
	    echo "OK"
	    echo ""
	    rm -rf ${EXEC_PATH}/tmp.txt
	fi
	
	# 浡ǽǻѤƤ륳ޥɤΥѥå̵ͭå
	for p_name in ${CHECK_PACKAGE[@]}
	do
	    rpm_check ${p_name}
	    if [ ${check_flg} = 1 ]; then
	        echo ${p_name} >> ${EXEC_PATH}/tmp.txt
	    fi
	done
	
	#̤ɽ
	if [ -s ${EXEC_PATH}/tmp.txt ]; then
	    echo ""
	    echo "ٹ𡧰浡ǽƻѤˤϰʲΥѥåӥ󥹥ȡ뤹ɬפޤ"
	    cat ${EXEC_PATH}/tmp.txt
	    echo ""
	    echo "ܺ٤ˤĤƤϥ󥹥ȡޥ˥奢 P8 򻲾ȤƲ"
	    echo ""
	    sleep 2
	    rm -rf ${EXEC_PATH}/tmp.txt
	fi
	
	rm -rf ${EXEC_PATH}/tmp.txt
	
	##
	## ѥåΥå END
	##
}


##
## 󥹥ȡ
##
while [ 1 ];
do
  echo "Hinemos  "
  echo "     1) 󥹥ȡ"
  echo "     2) 󥤥󥹥ȡ"
  echo "     9) 󥹥ȡνλ"
  echo ""
  echo -n "===> "
  
  read CHOSEN_NUMBER
  
  case ${CHOSEN_NUMBER} in
      1)      
	  
	  echo ""
	  echo "ȥåȥåפԤޤ"
	  echo ""
	  echo ""

		while [ 1 ];
		  do
		  echo "󥹥ȡ򳫻ϤޤǤ?(Y/N)"
		  read ANS
		  case ${ANS} in
		      y|Y)
			  
			  # 󥹥ȡʬ
			  
			  # ǧ
			  pre_install
			  
			  if [ ! -d ${HINEMOS_AGENT_HOME} ]; then
			      echo "${HINEMOS_AGENT_HOME}¸ߤޤ󡣺ޤ"
			      echo "mkdir -p ${HINEMOS_AGENT_HOME}" 
			      echo ""
			  fi

			  while [ ! "${IPADDR}" ] ;
			  do
			      echo -n "ޥ͡IPɥ쥹ϤƲ"
			      read IPADDR
			  done
			
			  # ԡ
			  echo "ɬפʥեΥԡ򳫻Ϥޤ"
			  cp -pr $EXEC_PATH/hinemos_agent /opt
			  cp -p $EXEC_PATH/hinemos_agent.cfg ${HINEMOS_AGENT_HOME}/bin
			  echo "ɬפʥեΥԡλޤ"
			  echo ""
			  echo "JREΥ󥹥ȡ򤪤ʤޤ"
			  sleep 2
			  echo ""
			  cp ${EXEC_PATH}/jre-1_5_0_09-linux-i586.bin ${HINEMOS_AGENT_HOME}
			  CURRENT_DIR=`pwd`
			  cd ${HINEMOS_AGENT_HOME}
			  ${HINEMOS_AGENT_HOME}/jre-1_5_0_09-linux-i586.bin
			  rm ${HINEMOS_AGENT_HOME}/jre-1_5_0_09-linux-i586.bin
			  cd $CURRENT_DIR
			
			  # ֥ȤؤΥޥ͡IPɥ쥹ȿ
			  sed "s/%%manager%%/$IPADDR/" ${HINEMOS_AGENT_HOME}/lib/agent/Agent.properties > ${HINEMOS_AGENT_HOME}/lib/agent/Agent.properties_tmp
			  mv -f ${HINEMOS_AGENT_HOME}/lib/agent/Agent.properties_tmp ${HINEMOS_AGENT_HOME}/lib/agent/Agent.properties

			  # žȤؤΥޥ͡IPɥ쥹ȿ
                          sed "s/%%manager%%/$IPADDR/" ${HINEMOS_AGENT_HOME}/lib/log_agent/Agent.properties > ${HINEMOS_AGENT_HOME}/lib/log_agent/Agent.properties_tmp
                          mv -f ${HINEMOS_AGENT_HOME}/lib/log_agent/Agent.properties_tmp ${HINEMOS_AGENT_HOME}/lib/log_agent/Agent.properties

			  #ؤΥۥ̾ȿǤΤ
			  sed "s/%%HOST%%/$HOST/" ${HINEMOS_AGENT_HOME}/lib/log_agent/log4j.properties > ${HINEMOS_AGENT_HOME}/lib/log_agent/log4j.properties_tmp
                          mv -f ${HINEMOS_AGENT_HOME}/lib/log_agent/log4j.properties_tmp  ${HINEMOS_AGENT_HOME}/lib/log_agent/log4j.properties
 
			  #浡ǽΥåȥå
			  echo "浡ǽΥåȥåפԤʤäƤޤ"
			  echo ""
			  while [ 1 ] ;
			  do
				  echo "浡ǽμ¹ϤƲ"
				  echo "     1) ssh"
				  echo "     2) rsh"
				  echo ""
				  echo -n "===> "
				  read SHELL

				  case ${SHELL} in
					1)
					  break
					  ;;
					2)
					  echo "rsh" >> /etc/securetty
					  echo "${IPADDR} hinemos" > ~/.rhosts
					  break
					  ;;
					*)
					  echo ""
					  ;;
				  esac
			  done
			  
		          #ǽǽΥåȥå
			  echo "ǽǽΥåȥåפԤʤäƤޤ"
			  echo "Net-SNMPΥ󥹥ȡ"
			  rpm -Uvh --force --nosignature $SNMP_RPM
			  echo "view    systemview    included   .1.3.6.1 " >> /etc/snmp/snmpd.conf
			  echo "/etc/init.d/snmpd restart"
			  /etc/init.d/snmpd restart
			  echo "/sbin/chkconfig --level 345 snmpd on"
			  /sbin/chkconfig --level 345 snmpd on
			  
          		  #ƻǽΥåȥå
			  echo "ƻǽΥåȥåפԤʤäƤޤ"
			  echo ""
			  TMP_M=0
			  TMP_A=0
			  TMP_DNS=0
			  
			  grep "add for Hinemos Manager" /etc/syslog-ng/syslog-ng.conf > /dev/null 2>&1 && TMP_M=1
			  grep "add for Hinemos Agent" /etc/syslog-ng/syslog-ng.conf > /dev/null 2>&1 && TMP_A=1

			  if [ "${TMP_M}" -eq 0 ] ; then
				if [ "${TMP_A}" -eq 0 ] ; then
				  echo "syslog-ngΥ󥹥ȡ"
				  rpm -Uvh --force $SYSLOG_NG_RPM
				  LOCAL_ADDR=`grep $HOST $HOSTS_FILE | grep -v ^\# | gawk '{print $1}'`
				  echo "#add for Hinemos Agent" >> /etc/syslog-ng/syslog-ng.conf
				  echo "filter f_hinemos_log { facility(user);  };" >> /etc/syslog-ng/syslog-ng.conf
				  echo "source s_netudp { udp(ip($LOCAL_ADDR) port(514)); };" >>/etc/syslog-ng/syslog-ng.conf
				  echo "log { source(s_netudp); filter(f_hinemos_log); destination(d_hinemos);};" >>/etc/syslog-ng/syslog-ng.conf
				  echo "destination d_hinemos { tcp(\"${IPADDR}\" port(514));};" >> /etc/syslog-ng/syslog-ng.conf
				  echo "log { source(s_local);filter(f_messages);destination(d_hinemos);};" >> /etc/syslog-ng/syslog-ng.conf
				fi
			  fi
			  
			  # /etc/syslog-ng/syslog-ng.conf use_dns Խ
			  grep "use_dns" /etc/syslog-ng/syslog-ng.conf | grep "yes" > /dev/null 2>&1 && TMP_DNS=1
			  
			  if [ "${TMP_DNS}" -eq 0 ] ; then

				  SYSLOG_NG_TMP=`grep "use_dns" /etc/syslog-ng/syslog-ng.conf`
				  SYSLOG_NG_TMP_INSERT=`echo ${SYSLOG_NG_TMP} | sed "s/no/yes/g"`
				  
				  sed "s/${SYSLOG_NG_TMP}/#${SYSLOG_NG_TMP}\n\t${SYSLOG_NG_TMP_INSERT}/g" /etc/syslog-ng/syslog-ng.conf > /etc/syslog-ng/syslog-ng.conf_tmp
				  mv -f /etc/syslog-ng/syslog-ng.conf_tmp /etc/syslog-ng/syslog-ng.conf
				  
			  fi
			  
			  # syslogߡsyslog-ngεư
			  /etc/init.d/syslog stop
			  /etc/init.d/syslog-ng start
			  /sbin/chkconfig --level 2345 syslog off
			  /sbin/chkconfig --level 2345 syslog-ng on
			  
			  echo ""

		      break
		      ;;

		      n|N)
			  echo "󥹥ȡߤƥ˥塼ޤ"
			  echo ""
			  sleep 1
			  break
			  ;;
		      *)
		  esac
		done
                ;;
      2)      
	  echo "HinemosȤ򥢥󥤥󥹥ȡ뤷ޤǤ?(Y/N)"
	  read ANS
	  case ${ANS} in
	      y|Y)
		TMP=0
		grep "add for Hinemos Manager" /etc/syslog-ng/syslog-ng.conf > /dev/null 2>&1 && TMP=1
		if [ !"${TMP}" ] ; then
			echo "Syslog-ngߤޤ"
			  /etc/init.d/syslog-ng stop
			  /etc/init.d/syslog start
		 	  /sbin/chkconfig --level 2345 syslog on
			  /sbin/chkconfig --level 2345 syslog-ng off
		fi

		echo "Net-SNMPߤޤ"
		 /etc/init.d/snmpd stop
		 /sbin/chkconfig --level 2345 snmpd off

		 TMP=0
		 tail -1 /etc/snmp/snmpd.conf | grep "view    systemview    included   .1.3.6.1 " > /dev/null 2>&1 && TMP=1
		 if [ ${TMP} ] ; then
			COUNT=`cat /etc/snmp/snmpd.conf | wc -l`
		 	COUNT=`expr ${COUNT} - 1`
			head -${COUNT} /etc/snmp/snmpd.conf >/etc/snmp/snmpd.conf_hinemos_back
			mv /etc/snmp/snmpd.conf_hinemos_back /etc/snmp/snmpd.conf
		 fi 
		
		grep "rsh" /etc/securetty > /dev/null 2>&1
		TMP=$?
		if [ ${TMP} -eq 0 ] ; then
			echo "/etc/securettyrshޤ?(Y/N)"
			read TTY
			case ${TTY} in
			y|Y)
				grep -v rsh /etc/securetty > /etc/securetty.tmp
				mv /etc/securetty.tmp /etc/securetty
			;;
			*)
			;;
			esac
		fi
		if [ -f /root/.rhosts ] ; then
                        echo "/root/.rhosts ޤ?(Y/N)"
                        read RHOSTS
                        case ${RHOSTS} in
                        y|Y)
                                rm /root/.rhosts
                        ;;
                        *)
                        ;;
                        esac
                fi

		 rm -fr ${HINEMOS_AGENT_HOME}
		;;
	      *)
		;;
	  esac
	  echo ""
	  ;;
      9)      
	  echo "Hinemos 󥹥ȡλޤ"
	  exit
	  ;;
	*)
	  echo ""
	  sleep 1
	  ;;
  esac
done

==> hinemos_agent-2.3.0_rhel3_yomosugar.tar.gz: Hinemos_Agent-2.3.0_rhel3_Yomosugar/agent_installer_JP.sh <==
#!/bin/sh

#Copyright (C) 2006, 2007 NTT DATA Corporation
#
#This program is free software; you can redistribute it and/or
#Modify it under the terms of the GNU General Public License
#as published by the Free Software Foundation, version 2.
#
#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details

#ɤ߹ 
export EXEC_PATH=${0%/*}

. ${EXEC_PATH}/install.cfg

echo ""
                                                                                
echo "###################################################################"
echo "###                                                             ###"
echo "### Ѵեȥ Hinemos                    ###"
echo "###                                   󥹥ȡ   Ver 2.3.0  ###"
echo "###                                                             ###"
echo "###  Copyright (C) 2006,2007 NTT DATA Corporation.              ###"
echo "###################################################################"


EXEC_USER=`/usr/bin/whoami`
HOSTS_FILE=/etc/hosts
HOST=`hostname`

# check for incorrect user

if [ $EXEC_USER != "root" ]; then
        echo "";
        echo "ERROR  Hinemos AgentΥ󥹥ȡrootǤʤäƤ ";
        echo "";
        exit 1;
fi

pre_install() {
	##
	## hostsեΥå START
	##
	echo ""
	echo "󥹥ȡԤˡ${HOSTS_FILE} ΥåԤޤ"
	echo ""
	
	#ۥ̾IPɥ쥹νʣʤåԤ
	check_flg=`grep ${HOST} ${HOSTS_FILE} | grep -v ^\# | awk '{print $1}' | wc -l`
	
	if [ ${check_flg} != 1 ]; then
	    echo "NG"
	    echo "${HOSTS_FILE} ϡ${HOST} ФIPɥ쥹꤬ԤƤʤ2İʾIPɥ쥹ꤵƤޤ"
	    echo "ĤȤʤ褦ѹƲ"
	    echo ""
	    exit 1
	fi
	echo "OK"
	
	##
	## hostsեΥå END
	##
	
	
	##
	## ѥåΥå START
	##
	echo ""
	echo "󥹥ȡԤˡѥåΥåԤޤ"
	
	# ѥå̵ͭå
	rpm_check() {
	    rpm -qi $1 >/dev/null 2>&1
	    check_flg=$?
	}
	
	# ޥ˥奢˵ҤƤѥå̵ͭå
	for p_name in ${CHECK_MAN[@]}
	do
	    rpm_check ${p_name}
	    if [ ${check_flg} = 1 ]; then
	        echo ${p_name} >> ${EXEC_PATH}/tmp.txt
	    fi
	done
	
	# ̤ɽ
	if [ -s ${EXEC_PATH}/tmp.txt ]; then
	    echo ""
	    echo "NG"
	    echo "HinemosȤ򥤥󥹥ȡ뤹ˤϰʲΥѥå­Ƥޤ"
	    cat ${EXEC_PATH}/tmp.txt
	    echo ""
	    echo "ܺ٤ˤĤƤϥ󥹥ȡޥ˥奢 P8 򻲾ȤƲ"
	    echo ""
	    rm -rf ${EXEC_PATH}/tmp.txt
	    exit 1
	else
	    rm -rf ${EXEC_PATH}/tmp.txt
	fi
	
	# 󥹥ȡ뤹ѥåΰ¸طå
	for p_name in "${CHECK_RPMS[@]}"
	do
	    rpm -U --force --nosignature --test "${p_name}" >/dev/null 2>> ${EXEC_PATH}/tmp.txt
	done
	
	#̤ɽ
	if [ -s ${EXEC_PATH}/tmp.txt ]; then
	    echo "NG"
	    echo "HinemosȤ򥤥󥹥ȡ뤹ˤϰʲΥѥå­Ƥޤ"
	    cat ${EXEC_PATH}/tmp.txt |grep -v : |awk '{print $1}'
	    echo ""
	    echo "ܺ٤ˤĤƤϥ󥹥ȡޥ˥奢 P8 򻲾ȤƲ"
	    echo ""
	    rm -rf ${EXEC_PATH}/tmp.txt
	    exit 1
	else
	    echo "OK"
	    echo ""
	    rm -rf ${EXEC_PATH}/tmp.txt
	fi
	
	# 浡ǽǻѤƤ륳ޥɤΥѥå̵ͭå
	for p_name in ${CHECK_PACKAGE[@]}
	do
	    rpm_check ${p_name}
	    if [ ${check_flg} = 1 ]; then
	        echo ${p_name} >> ${EXEC_PATH}/tmp.txt
	    fi
	done
	
	#̤ɽ
	if [ -s ${EXEC_PATH}/tmp.txt ]; then
	    echo ""
	    echo "ٹ𡧰浡ǽƻѤˤϰʲΥѥåӥ󥹥ȡ뤹ɬפޤ"
	    cat ${EXEC_PATH}/tmp.txt
	    echo ""
	    echo "ܺ٤ˤĤƤϥ󥹥ȡޥ˥奢 P8 򻲾ȤƲ"
	    echo ""
	    sleep 2
	    rm -rf ${EXEC_PATH}/tmp.txt
	fi
	
	rm -rf ${EXEC_PATH}/tmp.txt
	
	##
	## ѥåΥå END
	##
}


##
## 󥹥ȡ
##
while [ 1 ];
do
  echo "Hinemos  "
  echo "     1) 󥹥ȡ"
  echo "     2) 󥤥󥹥ȡ"
  echo "     9) 󥹥ȡνλ"
  echo ""
  echo -n "===> "
  
  read CHOSEN_NUMBER
  
  case ${CHOSEN_NUMBER} in
      1)      
	  
	  echo ""
	  echo "ȥåȥåפԤޤ"
	  echo ""
	  echo ""

		while [ 1 ];
		  do
		  echo "󥹥ȡ򳫻ϤޤǤ?(Y/N)"
		  read ANS
		  case ${ANS} in
		      y|Y)
			  
			  # 󥹥ȡʬ
			  
			  # ǧ
			  pre_install
			  
			  if [ ! -d ${HINEMOS_AGENT_HOME} ]; then
			      echo "${HINEMOS_AGENT_HOME}¸ߤޤ󡣺ޤ"
			      echo "mkdir -p ${HINEMOS_AGENT_HOME}" 
			      echo ""
			  fi

			  while [ ! "${IPADDR}" ] ;
			  do
			      echo -n "ޥ͡IPɥ쥹ϤƲ"
			      read IPADDR
			  done
			
			  # ԡ
			  echo "ɬפʥեΥԡ򳫻Ϥޤ"
			  cp -pr $EXEC_PATH/hinemos_agent /opt
			  cp -p $EXEC_PATH/hinemos_agent.cfg ${HINEMOS_AGENT_HOME}/bin
			  echo "ɬפʥեΥԡλޤ"
			  echo ""
			  echo "JREΥ󥹥ȡ򤪤ʤޤ"
			  sleep 2
			  echo ""
			  cp ${EXEC_PATH}/jre-1_5_0_09-linux-i586.bin ${HINEMOS_AGENT_HOME}
			  CURRENT_DIR=`pwd`
			  cd ${HINEMOS_AGENT_HOME}
			  ${HINEMOS_AGENT_HOME}/jre-1_5_0_09-linux-i586.bin
			  rm ${HINEMOS_AGENT_HOME}/jre-1_5_0_09-linux-i586.bin
			  cd $CURRENT_DIR
			
			  # ֥ȤؤΥޥ͡IPɥ쥹ȿ
			  sed "s/%%manager%%/$IPADDR/" ${HINEMOS_AGENT_HOME}/lib/agent/Agent.properties > ${HINEMOS_AGENT_HOME}/lib/agent/Agent.properties_tmp
			  mv -f ${HINEMOS_AGENT_HOME}/lib/agent/Agent.properties_tmp ${HINEMOS_AGENT_HOME}/lib/agent/Agent.properties

			  # žȤؤΥޥ͡IPɥ쥹ȿ
                          sed "s/%%manager%%/$IPADDR/" ${HINEMOS_AGENT_HOME}/lib/log_agent/Agent.properties > ${HINEMOS_AGENT_HOME}/lib/log_agent/Agent.properties_tmp
                          mv -f ${HINEMOS_AGENT_HOME}/lib/log_agent/Agent.properties_tmp ${HINEMOS_AGENT_HOME}/lib/log_agent/Agent.properties

			  #ؤΥۥ̾ȿǤΤ
			  sed "s/%%HOST%%/$HOST/" ${HINEMOS_AGENT_HOME}/lib/log_agent/log4j.properties > ${HINEMOS_AGENT_HOME}/lib/log_agent/log4j.properties_tmp
                          mv -f ${HINEMOS_AGENT_HOME}/lib/log_agent/log4j.properties_tmp  ${HINEMOS_AGENT_HOME}/lib/log_agent/log4j.properties
 
			  #浡ǽΥåȥå
			  echo "浡ǽΥåȥåפԤʤäƤޤ"
			  echo ""
			  while [ 1 ] ;
			  do
				  echo "浡ǽμ¹ϤƲ"
				  echo "     1) ssh"
				  echo "     2) rsh"
				  echo ""
				  echo -n "===> "
				  read SHELL

				  case ${SHELL} in
					1)
					  break
					  ;;
					2)
					  echo "rsh" >> /etc/securetty
					  echo "${IPADDR} hinemos" > ~/.rhosts
					  break
					  ;;
					*)
					  echo ""
					  ;;
				  esac
			  done
			  
		          #ǽǽΥåȥå
			  echo "ǽǽΥåȥåפԤʤäƤޤ"
			  echo "Net-SNMPΥ󥹥ȡ"
			  rpm -Uvh --force --nosignature $SNMP_RPM
			  echo "view    systemview    included   .1.3.6.1 " >> /etc/snmp/snmpd.conf
			  echo "/etc/init.d/snmpd restart"
			  /etc/init.d/snmpd restart
			  echo "/sbin/chkconfig --level 345 snmpd on"
			  /sbin/chkconfig --level 345 snmpd on
			  
          		  #ƻǽΥåȥå
			  echo "ƻǽΥåȥåפԤʤäƤޤ"
			  echo ""
			  TMP_M=0
			  TMP_A=0
			  TMP_DNS=0
			  
			  grep "add for Hinemos Manager" /etc/syslog-ng/syslog-ng.conf > /dev/null 2>&1 && TMP_M=1
			  grep "add for Hinemos Agent" /etc/syslog-ng/syslog-ng.conf > /dev/null 2>&1 && TMP_A=1

			  if [ "${TMP_M}" -eq 0 ] ; then
				if [ "${TMP_A}" -eq 0 ] ; then
				  echo "syslog-ngΥ󥹥ȡ"
				  rpm -Uvh --force $SYSLOG_NG_RPM
				  LOCAL_ADDR=`grep $HOST $HOSTS_FILE | grep -v ^\# | gawk '{print $1}'`
				  echo "#add for Hinemos Agent" >> /etc/syslog-ng/syslog-ng.conf
				  echo "filter f_hinemos_log { facility(user);  };" >> /etc/syslog-ng/syslog-ng.conf
				  echo "source s_netudp { udp(ip($LOCAL_ADDR) port(514)); };" >>/etc/syslog-ng/syslog-ng.conf
				  echo "log { source(s_netudp); filter(f_hinemos_log); destination(d_hinemos);};" >>/etc/syslog-ng/syslog-ng.conf
				  echo "destination d_hinemos { tcp(\"${IPADDR}\" port(514));};" >> /etc/syslog-ng/syslog-ng.conf
				  echo "log { source(s_local);filter(f_mesg);destination(d_hinemos);};" >> /etc/syslog-ng/syslog-ng.conf
				fi
			  fi
			  
			  # /etc/syslog-ng/syslog-ng.conf use_dns Խ
			  grep "use_dns" /etc/syslog-ng/syslog-ng.conf | grep "yes" > /dev/null 2>&1 && TMP_DNS=1
			  
			  if [ "${TMP_DNS}" -eq 0 ] ; then

				  SYSLOG_NG_TMP=`grep "use_dns" /etc/syslog-ng/syslog-ng.conf`
				  SYSLOG_NG_TMP_INSERT=`echo ${SYSLOG_NG_TMP} | sed "s/no/yes/g"`
				  
				  sed "s/${SYSLOG_NG_TMP}/#${SYSLOG_NG_TMP}\n\t${SYSLOG_NG_TMP_INSERT}/g" /etc/syslog-ng/syslog-ng.conf > /etc/syslog-ng/syslog-ng.conf_tmp
				  mv -f /etc/syslog-ng/syslog-ng.conf_tmp /etc/syslog-ng/syslog-ng.conf
				  
			  fi
			  
			  # syslogߡsyslog-ngεư
			  /etc/init.d/syslog stop
			  /etc/init.d/syslog-ng start
			  /sbin/chkconfig --level 2345 syslog off
			  /sbin/chkconfig --level 2345 syslog-ng on
			  
			  echo ""

		      break
		      ;;

		      n|N)
			  echo "󥹥ȡߤƥ˥塼ޤ"
			  echo ""
			  sleep 1
			  break
			  ;;
		      *)
		  esac
		done
                ;;
      2)      
	  echo "HinemosȤ򥢥󥤥󥹥ȡ뤷ޤǤ?(Y/N)"
	  read ANS
	  case ${ANS} in
	      y|Y)
		TMP=0
		grep "add for Hinemos Manager" /etc/syslog-ng/syslog-ng.conf > /dev/null 2>&1 && TMP=1
		if [ !"${TMP}" ] ; then
			echo "Syslog-ngߤޤ"
			  /etc/init.d/syslog-ng stop
			  /etc/init.d/syslog start
		 	  /sbin/chkconfig --level 2345 syslog on
			  /sbin/chkconfig --level 2345 syslog-ng off
		fi

		echo "Net-SNMPߤޤ"
		 /etc/init.d/snmpd stop
		 /sbin/chkconfig --level 2345 snmpd off

		 TMP=0
		 tail -1 /etc/snmp/snmpd.conf | grep "view    systemview    included   .1.3.6.1 " > /dev/null 2>&1 && TMP=1
		 if [ ${TMP} ] ; then
			COUNT=`cat /etc/snmp/snmpd.conf | wc -l`
		 	COUNT=`expr ${COUNT} - 1`
			head -${COUNT} /etc/snmp/snmpd.conf >/etc/snmp/snmpd.conf_hinemos_back
			mv /etc/snmp/snmpd.conf_hinemos_back /etc/snmp/snmpd.conf
		 fi 
		
		grep "rsh" /etc/securetty > /dev/null 2>&1
		TMP=$?
		if [ ${TMP} -eq 0 ] ; then
			echo "/etc/securettyrshޤ?(Y/N)"
			read TTY
			case ${TTY} in
			y|Y)
				grep -v rsh /etc/securetty > /etc/securetty.tmp
				mv /etc/securetty.tmp /etc/securetty
			;;
			*)
			;;
			esac
		fi
		if [ -f /root/.rhosts ] ; then
                        echo "/root/.rhosts ޤ?(Y/N)"
                        read RHOSTS
                        case ${RHOSTS} in
                        y|Y)
                                rm /root/.rhosts
                        ;;
                        *)
                        ;;
                        esac
                fi

		 rm -fr ${HINEMOS_AGENT_HOME}
		;;
	      *)
		;;
	  esac
	  echo ""
	  ;;
      9)      
	  echo "Hinemos 󥹥ȡλޤ"
	  exit
	  ;;
	*)
	  echo ""
	  sleep 1
	  ;;
  esac
done
